# Support

If you're looking for support for Kinto there are a lot of options, check out:

* Team blog (archive) - https://mozilla-services.github.io/servicedenuages.fr/en
* Stack Overflow &mdash;  [questions tagged kinto on Stack Overflow](http://stackoverflow.com/questions/tagged/kinto)
* IRC &mdash; join `#kinto` on `irc.freenode.net` ([webclient](https://kiwiirc.com/client/irc.freenode.net/?#kinto))
* Slack &mdash; [Join the Kinto Slack team](https://slack.kinto-storage.org/)
* Mailing list &mdash; [See kinto mailing list archives](https://mail.mozilla.org/listinfo/kinto)
* Twitter &mdash; Use [`#Kinto`](https://twitter.com/search?q=%23Kinto)
